# evolvedominion
A text-based interface for evolving---and, playing against---strategies for Dominion.

This project was created as a proof of concept that minimally sophisticated agents
which rely only on local information could attain competent play through the use
of a genetic algorithm.

![Tests](https://github.com/arcboundrav/evodom/actions/workflows/tests.yml/badge.svg)
